@font-face {
    font-family: 'Poppins';
    src: url("../fonts/Poppins-Regular.ttf") format('truetype');
}

* {
    font-family: 'Poppins', sans-serif;
}

body {
    min-height: 100vh;
    width: 100%;
    overflow-x: hidden;
}

.body-container {
    height: calc(100% - 50px);
    width: 100%;
}

.map_container {
    background: #e2efef;
    margin-top: 2ch;
    margin-left: 2ch;
    margin-right: 2ch;
    height: 100%;
}

.toolbar {
    height: 50px; /* Full-height: remove this if you want "auto" height */
    position: sticky; /* sticky Sidebar (stay in place on scroll) */
    z-index: 10; /* Stay on top */
    top: 0; /* Stay at the top */
    background-color: #11101d; /* Black */
    color: white;
    padding: 6px 14px;
}

.stops-section-menu {
    padding-top: 10px;
    padding-bottom: 10px;
}

.loading_screen {
    z-index: 20;
    position: fixed;
    height: 100%;
    width: 100%;
    background-color: white;
    text-align: center;
}
.loading_screen img {
    /* center vertically */
    top: 60%;
    -ms-transform: translateY(60%);
    transform: translateY(60%);
    /* center horizontally */
    text-align: center;
}

.fullscreen:-webkit-full-screen {
    height: 100%;
    margin: 0;
}
.fullscreen:-ms-fullscreen {
    height: 100%;
}

.fullscreen:fullscreen {
    height: 100%;
}

.fullscreen {
    margin-bottom: 10px;
    width: 100%;
    height: 70vh;
}

.map_container:-webkit-full-screen {
    top: 50px;
    width: 10%;
}

.map_container:-ms-fullscreen {
    top: 50px;
    width: 10%;
}

.map_container:fullscreen {
    top: 50px;
    width: 10%;
}

.custom_control_interaction {
    position: absolute;
    width: max-content;
    left: 60px;
    top: 18px;
}

.map-tool-item {
    position: relative;
    margin-left: 10px;
}

.map-tool-item-group-btn {
	  min-width: 140px;
}

/* Colors for Shapes section */
.orange_text{
    color: orange;
}
.green_text {
    color: green;
}
.blue_text {
    color: blue;
}
.red_text {
    color: red;
}
.black_text {
    color: black;
}

.h_menu {
    margin-top: 12px;
}

.toolbar > .btn {
    padding-top: 1px;
    padding-bottom: 1px;
    padding-left: 6px;
    padding-right: 6px;
    margin-top: 5px;
}

.notification_banner {
    position: fixed;
    top: 60px;
    height: 210px;
    width: 100%;
    z-index: 15;
    background-color:rgba(0, 0, 0, 0);
}

.notification_banner > .alert {
    margin-top: 10px;
}

.pointer-coor {
	  min-width: 20ch;
}

.se-horizontal-menu {
    margin-top: 2ch;
}

.se-sections-content{
    margin-top: 1.1cm;
    margin-left: 4ch;
    margin-right: 4ch;
    margin-bottom: 2cm;
}

.se-accordion-top-sp{
    margin-top: 0.6cm;
}

.se-col-min-width{
    min-width: 25ch;
}
