{# Uses vue variable to define which section is active and which is not #}
<!-- {% verbatim %} -->
<ul class="nav nav-tabs nav-fill h_menu" id="h_menu" role="tablist">
    <li
        v-for="element in activeSections"
        class="nav-item"
        role="presentation"
    >
    <button
      :class="['nav-link', currentActiveSection === element ? 'active' : '' ]"
      :id="'nav-'+element+'-tab'"
      data-bs-toggle="tab"
      :data-bs-target="'#nav-'+element"
      type="button"
      role="tab"
      :aria-controls="'nav-'+element"
      aria-selected="true"
    >
      {{dict[element]}}
    </button>
  </li>
</ul>
<!-- {% endverbatim %} -->
