# Generated by Django 3.1.7 on 2021-06-10 00:50

from django.db import migrations, models
import shapeeditor.models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Shape',
            fields=[
                ('shape_id', models.CharField(db_index=True, max_length=80, primary_key=True, serialize=False)),
                ('lines', models.JSONField(default=shapeeditor.models.default_shape_line)),
            ],
        ),
        migrations.CreateModel(
            name='Stop',
            fields=[
                ('stop_id', models.CharField(db_index=True, max_length=80, primary_key=True, serialize=False)),
                ('lines', models.JSONField(default=shapeeditor.models.default_stop_line)),
            ],
        ),
    ]
